.. _model-account.configuration:

Configuration
=============

The *Account Configuration* contains the settings used to configure the general
behaviour and default values for accounting related activities.

.. seealso::

   Account configuration settings are found by opening the main menu item:

      |Financial --> Configuration --> Configuration|__

      .. |Financial --> Configuration --> Configuration| replace:: :menuselection:`Financial --> Configuration --> Configuration`
      __ https://demo.tryton.org/model/account.configuration/1
